# -*- coding: utf8 -*-
from __future__ import unicode_literals

parser_class = "etimax"


def test_encode_order(self):
    message = self.order()
    expected = """
    H|\\^&
    P|1||123456||NYME^ANO||20110513|F
    O|1|||^^^A
    O|2|||^^^B
    L|1|N
    """
    assert message == expected


def test_void_order(self):
    message = self.order(
        worklist=self.void_worklist,
        context={
            "query": self.parse(
                """
            H|\\^&
            Q|1|123456||ALL||||||||O
            L|1|N"""
            )
        },
    )
    expected = """
    H|\\^&
    L|1|I
    """
    assert message == expected


def test_decode_query(self):
    worklist = self.decode(
        """
    H|\\^&
    Q|1|123456||ALL||||||||O
    L|1|N
    """
    )
    expected = {
        "context": "query",
        "samples": [{"type": "patient", "sample_id": "123456"}],
    }
    assert worklist == expected


def test_decode_result(self):
    worklist = self.decode(
        """
    H|\\^&|||ETIMAX
    P|1||282043141046||NYME^ANO||19660627|M
    O|1|||^^^HEVM2
    R|1|^^^HEVM2^Resultat|Neg
    C|1|I|Kit^14051^05/2015|I
    C|2|I|HEVM NC Ref : Negatif^14051^05/2015|I
    R|2|^^^HEVM2^Index|0.14|IU/ml
    P|2||282013111322
    O|1|||^^^HEVM2
    R|1|^^^HEVM2^Resultat|Neg
    C|1|I|Kit^14051^05/2015|I
    C|2|I|HEVM NC Ref : Negatif^14051^05/2015|I
    R|2|^^^HEVM2^Index|0.06|IU/ml
    L|1|N
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "282043141046",
                "results": [
                    {"code": "HEVM2^Resultat", "value": "Neg"},
                    {"code": "HEVM2^Index", "value": "0.14"},
                ],
            },
            {
                "type": "patient",
                "sample_id": "282013111322",
                "results": [
                    {"code": "HEVM2^Resultat", "value": "Neg"},
                    {"code": "HEVM2^Index", "value": "0.06"},
                ],
            },
        ],
    }
    assert worklist == expected
