# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime

from driverng.tests import BaseTest
from driverng.transport.tcp_ihe import TCPIHETransport


class AtellicaTest(BaseTest):
    def get_transport(self):
        return TCPIHETransport(
            host_send="127.0.0.1",
            port_send=6565,
            host_recv="127.0.0.1",
            port_recv=6566,
            logger=self._logger,
        )


MESSAGE = """MSH|^~\\&|Siemens Analyzer||OM_LAB_ANAYLYZER_MGR|||OML^033^OML_03320130715141912||1374155237204|P|2.5.1|||NE|||UNIDECODE UTF-8|||LAB-29^IHE~LAW_REFLEX^IHE~LAW_SPECIMEN^IHE~LAW_RERUN^IHE~LAW_CONTAINER^IHE~LAW_DILUTIONS^IHE~LAW_PAT_DEM^IHE
PID|1||036666666||NYME^ANO||20110513|F
PV1|1||LOC
SPM|1|123456||Serum|||||||P||||||20130513114242|20130603110342
SAC|||123456
TQ1|||||||||A
OBR|1|||A|||||||G
SPM|1|123456||Serum|||||||P||||||20130513114242|20130603110342
SAC|||123456
TQ1|||||||||A
OBR|1|||B|||||||G"""


MESSAGE_QUERY = """MSH|^~\\&|UIW_LIS|""|LIS_ID|""|20180221172905+0100||QBP^Q11^QBP_Q11|167a1789535548f9a682d1b4a2944afb|P|2.5.1|||NE|AL||UNICODE UTF-8|||LAB-27^IHE~LAW_REFLEX^IHE~LAW_SPECIMEN^IHE~LAW_RERUN^IHE~LAW_CONTAINER^IHE~LAW_DILUTIONS^IHE~LAW_PAT_DEM^IHE
QPD|WOS^Work OrderStep^IHELAW|c7c46456fc5f4e62becf14698f93aeb3|999000000101
RCP|I||R^RealTime^HL70394"""


class TestProtocolAtellica(AtellicaTest):
    PROTOCOL_CLASS = "mllp_hl7v2"

    def test_send_recv(self):
        self.P.transport.transport_recv = self.P.transport.transport
        self.assertSendRecvMessageEqual(
            MESSAGE,
            """send <vt>MSH|^~\\&|Siemens Analyzer||OM_LAB_ANAYLYZER_MGR|||OML^033^OML_03320130715141912||1374155237204|P|2.5.1|||NE|||UNIDECODE UTF-8|||LAB-29^IHE~LAW_REFLEX^IHE~LAW_SPECIMEN^IHE~LAW_RERUN^IHE~LAW_CONTAINER^IHE~LAW_DILUTIONS^IHE~LAW_PAT_DEM^IHE<cr>PID|1||036666666||NYME^ANO||20110513|F<cr>PV1|1||LOC<cr>SPM|1|123456||Serum|||||||P||||||20130513114242|20130603110342<cr>SAC|||123456<cr>TQ1|||||||||A<cr>OBR|1|||A|||||||G<cr>SPM|1|123456||Serum|||||||P||||||20130513114242|20130603110342<cr>SAC|||123456<cr>TQ1|||||||||A<cr>OBR|1|||B|||||||G<cr><fs><cr>
            recv <vt>MSH|^~\\&|MCA^HOST||S02^ZENIT||20130715141912||ORL^034^ORL_042|1374155237204|P|2.5<cr>MSA|AA|1374155237204|<fs><cr>""",
        )

    def test_ack(self):
        message = self.P.get_ack_message(
            MESSAGE.encode(),
            date=datetime.datetime(2014, 1, 1, 12, 42, 24),
            control_id=b"CONTROLID",
        )
        expected = b'MSH|^~\\&|OM_LAB_ANAYLYZER_MGR|""|Siemens Analyzer|""|20140101124224||ACK^R22^ACK|CONTROLID|P|2.5.1|||NE|AL||UNICODE UTF-8|||LAB-29^IHE\rMSA|AA|1374155237204|\r'
        assert message == expected

    def test_rsp(self):
        message = self.P.get_ack_message(
            MESSAGE_QUERY.encode(),
            date=datetime.datetime(2018, 2, 21, 17, 37, 5),
            control_id=b"CONTROLID",
        )
        expected = b'MSH|^~\\&|LIS_ID|""|UIW_LIS|""|20180221173705||RSP^K11^RSP_K11|CONTROLID|P|2.5.1|||NE|||UNICODE UTF-8|||LAB-27^IHE\rMSA|AA|167a1789535548f9a682d1b4a2944afb\rQAK|c7c46456fc5f4e62becf14698f93aeb3|OK|WOS^Work Order Step^IHELAW\rQPD|WOS^Work Order Step^IHELAW|c7c46456fc5f4e62becf14698f93aeb3|999000000101'
        assert message == expected
