# -*- coding: utf-8 -*-

from __future__ import unicode_literals

import datetime

parser_class = "sqavision"


def test_decode_message(self):
    date = datetime.datetime(2021, 7, 29, 8, 7)
    message_trame = """
    O|SN#^5215^|SID^478010729005^|FIC^17^|ATM^08:07^|ADT^07/29/21^|ABS^3^|VOL^4,80^|APPR^1^|VISC^1^|LIQ^1^|PH^8,1^|WBCCONC^1^|ROUNCELL^2^|CONC^7,7^|MOT5^44^|MOT^N/A^|NPMOT5^30^|NPMOT^N/A^|IMMOT5^56^|IMMOT^N/A^|PMOT^45.8^|OPT1^^
    """
    worklist = self.decode(message_trame)
    expected = {
        "context": "result",
        "samples": [
            {
                "sample_id": "478010729005",
                "type": "patient",
                "results": [
                    {"code": "SN#", "value": "5215", "date": date},
                    {"code": "FIC", "value": "17", "date": date},
                    {"code": "ABS", "value": "3", "date": date},
                    {"code": "VOL", "value": "4,80", "date": date},
                    {"code": "APPR", "value": "1", "date": date},
                    {"code": "VISC", "value": "1", "date": date},
                    {"code": "LIQ", "value": "1", "date": date},
                    {"code": "PH", "value": "8,1", "date": date},
                    {"code": "WBCCONC", "value": "1", "date": date},
                    {"code": "ROUNCELL", "value": "2", "date": date},
                    {"code": "CONC", "value": "7,7", "date": date},
                    {"code": "MOT5", "value": "44", "date": date},
                    {"code": "MOT", "value": "N/A", "date": date},
                    {"code": "NPMOT5", "value": "30", "date": date},
                    {"code": "NPMOT", "value": "N/A", "date": date},
                    {"code": "IMMOT5", "value": "56", "date": date},
                    {"code": "IMMOT", "value": "N/A", "date": date},
                    {"code": "PMOT", "value": "45.8", "date": date},
                    {"code": "OPT1", "value": "", "date": date},
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_control(self):
    date = datetime.datetime(2018, 10, 26, 8, 7)
    message = "O|FIC^8^|CTY^1^|LOT^1^|EXD^01/00^|ATM^08:07^|ADT^10/26/18^|TAR^1.0^|RAN^1.0^|PH^8,1^|CTSC^5.3^|RST^1^|COA^1^|CMSC^^"
    worklist = self.decode(message)
    expected = {
        "context": "result",
        "samples": [
            {
                "sample_id": "1",
                "control_lot": "1",
                "type": "control",
                "results": [
                    {"code": "FIC", "value": "8", "date": date},
                    {"code": "CTY", "value": "1", "date": date},
                    {"code": "EXD", "value": "01/00", "date": date},
                    {"code": "TAR", "value": "1.0", "date": date},
                    {"code": "RAN", "value": "1.0", "date": date},
                    {"code": "PH", "value": "8,1", "date": date},
                    {"code": "CTSC", "value": "5.3", "date": date},
                    {"code": "RST", "value": "1", "date": date},
                    {"code": "COA", "value": "1", "date": date},
                    {"code": "CMSC", "value": "", "date": date},
                ],
            }
        ],
    }
    assert worklist == expected
